photosgallery/viewframework/texturemanager/src/glxtexturemanagerimpl.cpp
branchRCL_3
changeset 18 bcb43dc84c44
parent 14 ce1c7ad1f18b
child 32 78ad99c24f08
--- a/photosgallery/viewframework/texturemanager/src/glxtexturemanagerimpl.cpp	Mon Mar 15 12:40:30 2010 +0200
+++ b/photosgallery/viewframework/texturemanager/src/glxtexturemanagerimpl.cpp	Wed Mar 31 21:31:03 2010 +0300
@@ -892,45 +892,6 @@
     }
 
 // -----------------------------------------------------------------------------
-// DoHandleResolutionChangedL
-// -----------------------------------------------------------------------------
-//
-//To-do
-/*void CGlxTextureManagerImpl::DoHandleResolutionChangedL(TInt aIconIndex)
-    {
-    TGlxIcon& icon = iIconList[aIconIndex];
-    CAlfTexture* texture = icon.iTexture;
-    // Clear previous content
-    //texture->SetSegmentCountL(0);
-    
-    // Get new bitmaps
-    CFbsBitmap* bitmap = NULL;
-    CFbsBitmap* mask = NULL;
-    ProvideBitmapL(icon.iTextureId, bitmap, mask);
-    // Upload to texture
-    if(bitmap)
-        {
-        CleanupStack::PushL(bitmap);
-        texture->SetSize(bitmap->SizeInPixels());
-        if(mask)
-            {
-            CleanupStack::PushL(mask);
-            texture->UploadL( *bitmap, mask,
-                        EAlfTextureUploadFlagDefault );
-            CleanupStack::PopAndDestroy(mask);
-            }
-        else
-            {
-            texture->UploadL( *bitmap, NULL,
-                        EAlfTextureUploadFlagDefault );
-            
-            }
-        CleanupStack::PopAndDestroy(bitmap);    
-        }
-    }*/
-
-
-// -----------------------------------------------------------------------------
 // ProvideBitmapL
 // -----------------------------------------------------------------------------
 //
@@ -1108,9 +1069,9 @@
         // check if rights have expired
         TBool checkViewRights = (cat==EMPXImage);
 
-        //Fix for ESLM-82WJ59: Since uri can be either focused or unfocused item
-        //better call CheckOpenRightsL which doesn't modify lastconsumedUri.
-        drmInvalid = !iDrmUtility->CheckOpenRightsL(uri, checkViewRights);
+        //Since uri can be either focused or unfocused item
+        //better call ItemRightsValidityCheckL which doesn't modify lastconsumedUri.
+        drmInvalid = !iDrmUtility->ItemRightsValidityCheckL(uri, checkViewRights);
 
         CGlxMedia* properties = const_cast<CGlxMedia*>(aMedia.Properties());
         if( !drmInvalid )